@@ -21,6 +21,7 @@ from eodash_catalog.endpoints import (
     handle_collection_only,
     handle_custom_endpoint,
     handle_GeoDB_endpoint,
+    handle_rasdaman_endpoint,
     handle_raw_source,
     handle_SH_endpoint,
     handle_SH_WMS_endpoint,
@@ -132,6 +133,7 @@ def extract_indicator_info(parent_collection: Collection):
         "sensor",
         "cities",
         "countries",
+        "thumbnail",
     ]
     summaries: dict[str, Any] = {}
     for key in to_extract:
@@ -229,6 +231,10 @@ def process_collection_file(
                         collection = handle_xcube_endpoint(
                             catalog_config, endpoint_config, collection_config, catalog
                         )
+                    elif endpoint_config["Name"] == "rasdaman":
+                        collection = handle_rasdaman_endpoint(
+                            catalog_config, endpoint_config, collection_config, catalog
+                        )
                     elif endpoint_config["Name"] == "WMS":
                         collection = handle_WMS_endpoint(
                             catalog_config, endpoint_config, collection_config, catalog
