@@ -16,8 +16,9 @@ def get_SH_token(endpoint_config: dict) -> str:
         client_id = os.getenv(f"SH_CLIENT_ID_{env_id}", "")
         client_secret = os.getenv(f"SH_CLIENT_SECRET_{env_id}", "")
     # 10 minutes before end of validity
-    safety_buffer_validity = _token_cache[client_id]["expires_at"] - (60 * 10)
-    if client_id in _token_cache and (safety_buffer_validity) > (time.time()):
+    if client_id in _token_cache and (_token_cache[client_id]["expires_at"] - (60 * 10)) > (
+        time.time()
+    ):
         return _token_cache[client_id]["access_token"]
     # Create a session
     client = BackendApplicationClient(client_id=client_id)
