@@ -297,6 +297,11 @@ def add_collection_information(
                 roles=["thumbnail"],
             ),
         )
+        # Bubble up thumbnail to extra fields
+        collection.extra_fields["thumbnail"] = (
+            f'{catalog_config["assets_endpoint"]}/'
+            f'{collection_config["Image"]}'
+        )
     # Add extra fields to collection if available
     add_extra_fields(collection, collection_config)
 
@@ -317,6 +322,8 @@ def add_collection_information(
                     roles=["metadata"],
                 ),
             )
+    if "Colorlegend" in collection_config:
+        collection.extra_fields["eox:colorlegend"] = collection_config["Colorlegend"]
 
 
 def add_base_overlay_info(
